;; Generated package description from org-gnosis.el  -*- no-byte-compile: t -*-
(define-package "org-gnosis" "0.0.5" "Roam-like Knowledge Management System" '((emacs "27.2") (emacsql "4.0.0") (compat "29.1.4.2")) :commit "16142440ddb3a145bf054f2b9bc793f145fad110" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("extensions") :url "https://thanosapollo.org/projects/org-gnosis/")
